# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class AssistantFile(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    The unique identifier of the file.
    """

    object: typing.Optional[str] = None
    created_at: int = pydantic.Field()
    """
    The unix timestamp of when the file was created.
    """

    assistant_id: str = pydantic.Field()
    """
    The unique identifier of the assistant.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
